/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is FirefoxView Mozilla Extension.
 * The Initial Developer of the Original Code is Alex Sirota <alex@elbrus.com>. 
 * Portions created by Alex Sirota are Copyright (C) 2004 Alex Sirota. All Rights Reserved.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


function firefoxviewUninstallObserver() {
    this._guid = '{5D558C43-550F-4b12-84AB-0D8ABDA9F975}';
    this._observerService = Components.classes["@mozilla.org/observer-service;1"]
                                .getService(Components.interfaces.nsIObserverService);
    this._observerService.addObserver(this, "em-action-requested", false);

    try {
       Components.utils.import("resource://gre/modules/AddonManager.jsm");  
       AddonManager.addAddonListener(this);
    } catch(e) {  }

}

firefoxviewUninstallObserver.prototype = {
    uninstallFirefoxViewIEHooks : function() {
           	// we have been uninstalled, uninstall the menu items
        	firefoxViewUnInstall();
        	// clear the is_installed flag, so the next time the extension is installed
        	// the menu items will be installed automatically
        	firefoxviewClearInstalled();
    },

    observe: function(subject, topic, data) {
        if ((topic == "em-action-requested") && (data == "item-uninstalled")) {
            var item = subject.QueryInterface(Components.interfaces.nsIUpdateItem);
            if (item.id != this._guid) return;

            this.uninstallFirefoxViewIEHooks();
    
        }
    },

    removeObserver : function() {
        this._observerService.removeObserver(this, "em-action-requested");
    },

    // AddonListener
    onUninstalling  : function(addon, needsRestart) {
        if (addon.id == this._guid) {
            this.uninstallFirefoxViewIEHooks();
        }
    },

    onDisabling  : function(addon, needsRestart) {
        if (addon.id == this._guid) {
            this.uninstallFirefoxViewIEHooks();
        }
    },
}


function firefoxviewInitOverlay() {
   // the function returns null if there is no preference at all, meaning first time this is run
   if (firefoxviewIsInstalled() == null) {
	firefoxViewInstall();
   }

   gFirefoxViewUninstallObserver = new firefoxviewUninstallObserver();
}

function firefoxviewUnloadOverlay() {
   gFirefoxViewUninstallObserver.removeObserver(); 
}

addEventListener("load", firefoxviewInitOverlay, false);
addEventListener("unload", firefoxviewUnloadOverlay, false);

var gFirefoxViewUninstallObserver = null;
